import {
  faBars,
  faBookOpen,
  faCircleHalfStroke,
  faGavel,
  faGlobe,
  faXmark,
} from "@fortawesome/pro-regular-svg-icons";
import {
  useIsRouting,
  useLocation,
  useNavigate,
  useSearchParams,
} from "@solidjs/router";
import { createEffect, createSignal, onCleanup } from "solid-js";
import { FontAwesomeIcon } from "../FontAwesomeIcon";

export const [lightMode, setLightMode] = createSignal(false);

function Navbar() {
  const [menu, setMenu] = createSignal(false);
  const navigate = useNavigate();
  const location = useLocation();
  const [searchParams] = useSearchParams();
  const isRouting = useIsRouting();

  createEffect(() => {
    const mode = searchParams.lightMode;
    const prefersDarkMode =
      window.matchMedia &&
      window.matchMedia("(prefers-color-scheme: dark)").matches;
    if (typeof mode === "undefined") {
      setLightMode(!prefersDarkMode);
      return;
    }
    const parsedMode = JSON.parse(mode);
    if (typeof parsedMode !== "boolean") return;
    setLightMode(parsedMode);
  });

  createEffect(() => {
    if (!isRouting() || !menu()) return;
    setMenu(false);
  });

  const handleKeyDown = (event: KeyboardEvent) => {
    if (!menu() || "Escape" != event.key) return;
    event.preventDefault();
    setMenu(false);
  };

  createEffect(() => {
    window.addEventListener("keydown", handleKeyDown);
    onCleanup(() => {
      window.removeEventListener("keydown", handleKeyDown);
    });
  });

  return (
    <>
      <div id="navbar" style={{ visibility: menu() ? "visible" : "hidden" }}>
        <a href="/en/">
          <FontAwesomeIcon icon={faBookOpen} /> Introduction
        </a>

        <a href="/en/overview">
          <FontAwesomeIcon icon={faBookOpen} /> Start
        </a>
        <ol>
          <li>
            <a href="/en/overview#start">What are EUCs?</a>
          </li>
          <li>
            <a href="/en/overview#why">Why EUCs?</a>
          </li>
          <li>
            <a href="/en/overview#funktion">Functionality</a>
          </li>
          <li>
            <a href="/en/overview#begriffe">Glossarry</a>
          </li>
          <li>
            <a href="/en/overview#sicherheit">Safety</a>
          </li>
          <li>
            <a href="/en/overview#ausrüstung">Gear</a>
          </li>
          <li>
            <a href="/en/overview#cutout">Cut-out's</a>
          </li>
          <li>
            <a href="/en/overview#akkuss">Battery safety</a>
          </li>
          <li>
            <a href="/en/overview#fahrweise">Ride style</a>
          </li>
          <li>
            <a href="/en/overview#wobbles">Wobbles</a>
          </li>
          <li>
            <a href="/en/overview#leistung">Performance</a>
          </li>
          <li>
            <a href="/en/overview#federung">Suspension</a>
          </li>
          <li>
            <a href="/en/overview#reifen">Tires</a>
          </li>
          <li>
            <a href="/en/overview#historie">History</a>
          </li>
          <li>
            <a href="/en/overview#geraete">Device list</a>
          </li>
        </ol>

        <a href="/en/manufacturers">
          <FontAwesomeIcon icon={faBookOpen} /> Manufacturers
        </a>

        <a href="/de/imprint">
          <FontAwesomeIcon icon={faGavel} /> Legal Notice (DE)
        </a>

        <div class="modes">
          <button
            onClick={() => {
              const mode = !lightMode() ? "?lightMode=true" : "";
              const url = location.pathname + mode;
              navigate(url, {
                replace: true,
                scroll: false,
              });
            }}
          >
            {lightMode() ? "Dark Mode " : "Light Mode "}
            <FontAwesomeIcon icon={faCircleHalfStroke} />
          </button>
          <button
            onClick={() =>
              navigate("/de" + location.pathname.slice(3), { scroll: false })
            }
          >
            Deutsch <FontAwesomeIcon icon={faGlobe} />
          </button>
          <button onClick={() => setMenu(false)}>
            Close <FontAwesomeIcon icon={faXmark} />
          </button>
        </div>
      </div>

      <button class="menu" title="Menu" onClick={() => setMenu(true)}>
        <FontAwesomeIcon icon={faBars} />
      </button>
    </>
  );
}

export default Navbar;
